==> zio-aws-sagemaker_2.12-5.20.22.3-sources.jar: zio/aws/sagemaker/model/ModelExplainabilityJobInput.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModelExplainabilityJobInput(
    endpointInput: Optional[zio.aws.sagemaker.model.EndpointInput] =
      Optional.Absent,
    batchTransformInput: Optional[zio.aws.sagemaker.model.BatchTransformInput] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ModelExplainabilityJobInput = {
    import ModelExplainabilityJobInput.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ModelExplainabilityJobInput
      .builder()
      .optionallyWith(endpointInput.map(value => value.buildAwsValue()))(
        _.endpointInput
      )
      .optionallyWith(batchTransformInput.map(value => value.buildAwsValue()))(
        _.batchTransformInput
      )
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ModelExplainabilityJobInput.ReadOnly =
    zio.aws.sagemaker.model.ModelExplainabilityJobInput.wrap(buildAwsValue())
}
object ModelExplainabilityJobInput {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ModelExplainabilityJobInput
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ModelExplainabilityJobInput =
      zio.aws.sagemaker.model.ModelExplainabilityJobInput(
        endpointInput.map(value => value.asEditable),
        batchTransformInput.map(value => value.asEditable)
      )
    def endpointInput: Optional[zio.aws.sagemaker.model.EndpointInput.ReadOnly]
    def batchTransformInput
        : Optional[zio.aws.sagemaker.model.BatchTransformInput.ReadOnly]
    def getEndpointInput
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.EndpointInput.ReadOnly] =
      AwsError.unwrapOptionField("endpointInput", endpointInput)
    def getBatchTransformInput: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.BatchTransformInput.ReadOnly
    ] = AwsError.unwrapOptionField("batchTransformInput", batchTransformInput)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ModelExplainabilityJobInput
  ) extends zio.aws.sagemaker.model.ModelExplainabilityJobInput.ReadOnly {
    override val endpointInput
        : Optional[zio.aws.sagemaker.model.EndpointInput.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.endpointInput())
        .map(value => zio.aws.sagemaker.model.EndpointInput.wrap(value))
    override val batchTransformInput
        : Optional[zio.aws.sagemaker.model.BatchTransformInput.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.batchTransformInput())
        .map(value => zio.aws.sagemaker.model.BatchTransformInput.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ModelExplainabilityJobInput
  ): zio.aws.sagemaker.model.ModelExplainabilityJobInput.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_2.13-5.17.164.1-sources.jar: zio/aws/sagemaker/model/ModelExplainabilityJobInput.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class ModelExplainabilityJobInput(
    endpointInput: zio.aws.sagemaker.model.EndpointInput
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ModelExplainabilityJobInput = {
    import ModelExplainabilityJobInput.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ModelExplainabilityJobInput
      .builder()
      .endpointInput(endpointInput.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ModelExplainabilityJobInput.ReadOnly =
    zio.aws.sagemaker.model.ModelExplainabilityJobInput.wrap(buildAwsValue())
}
object ModelExplainabilityJobInput {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ModelExplainabilityJobInput
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ModelExplainabilityJobInput =
      zio.aws.sagemaker.model
        .ModelExplainabilityJobInput(endpointInput.asEditable)
    def endpointInput: zio.aws.sagemaker.model.EndpointInput.ReadOnly
    def getEndpointInput
        : ZIO[Any, Nothing, zio.aws.sagemaker.model.EndpointInput.ReadOnly] =
      ZIO.succeed(endpointInput)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ModelExplainabilityJobInput
  ) extends zio.aws.sagemaker.model.ModelExplainabilityJobInput.ReadOnly {
    override val endpointInput: zio.aws.sagemaker.model.EndpointInput.ReadOnly =
      zio.aws.sagemaker.model.EndpointInput.wrap(impl.endpointInput())
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ModelExplainabilityJobInput
  ): zio.aws.sagemaker.model.ModelExplainabilityJobInput.ReadOnly = new Wrapper(
    impl
  )
}
